@@ -1,7 +1,10 @@
 from django.contrib import admin
+from django.contrib.auth import get_user_model
 
 from .models import Dictionary, Newsletter, RssFeed
 
+User = get_user_model()
+
 
 class NewsletterAdmin(admin.ModelAdmin):
     pass
@@ -13,11 +16,13 @@ class DictionaryAdmin(admin.ModelAdmin):
 
 
 class RssFeedAdmin(admin.ModelAdmin):
-    search_fields = ("user", "feed")
     list_display = ("user", "feed")
     readonly_fields = ("feed",)
     raw_id_fields = ("user",)
 
+    def get_search_fields(self, request):
+        return {"feed", f"user__{User.USERNAME_FIELD}"}
+
 
 admin.site.register(Newsletter, NewsletterAdmin)
 admin.site.register(Dictionary, DictionaryAdmin)
